(By Chloe Mattia)

# A review of microbial interactions with soil respiration and applications of respiration measurements. 


## Introduction 

Soil respiration is a component of the global carbon cycle and also an important parameter of biological activity in the soil of terrestrial ecosystems (Janssens et al. 1998; Kucera and Kirkham 1971). Soil is a major pool for carbon and respiration is an efflux from that pool. 

Respiration from soil represents 25% of the global carbon dioxide (COImage) exchange (Jia et al. 2006). With important questions regarding human impact on the carbon cycle needing to be answered, analysis of soil respiration is an essential parameter to determine the sources and sinks of carbon, turnover rate of soil organic matter, and the biological activity of soil (Jia et al. 2006; Kucera and Kirkham 1971).  

Soil microorganisms are integrated with soil respiration. When taking soil respiration measurements, it must be separated into three biologically relevant compartments: root respiration, microbial respiration of rhizospheric carbon compounds, and respiration from the decomposition of soil organic matter (Janssens et al. 1998; Jia et al. 2006; Kelting et al. 1998; Kucera and Kirkham 1971; Kuzyakov 2002). Depending on the purpose of a study, 
differentiating between the three is necessary in order to ensure the right method of measuring is used. Several techniques exist to measure soil respiration and to partition the heterotrophic and autotrophic components, each varying in assumptions and procedure. Several researchers have sought to further understand the differences among the three components of soil respiration, and the methods used to measure them (Janssens et al. 1998; Kelting et al. 1998). In concurrence with these studies are others examining the relationship of root products and microorganisms (George et al. 2003; Lynch and Whipps 1990).  With this information future studies can more accurately calculate and model carbon budgets for terrestrial ecosystems, and therefore address issues such as climate and land use change (DeLucia et al. 2007; Jia et al. 2006; Kelting et al. 
1998). 

Following is an overview of studies to illustrate the interactions between the plant and microbial components of soil respiration, in addition to the relationship between soil respiration and changing environmental and biological conditions.  

### Rhizosphere 

The rhizosphere is defined as the soil region influenced by plant roots. Respiration from this region of soil has three components: COImage derived from root respiration, COImage from the microbial break-down of exudates, and COImage from the microbial decomposition of organic matter located in the soil of the rhizosphere (Kuzyakov 2002).  

Plant roots dispel exudates and other residues that are energy rich. Root-derived organic matter consists of water-soluble root exudates (e.g. sugars, amino acids, organic acids, hormones, vitamins) that leak, secretions (polymeric carbohydrates, enzymes) that are released by metabolic processes, and lysates (e.g. cell walls) that release when cells autolyse, and gases (e.g. ethylene, COImage) that are respired (Lynch and Whipps 1990). Root contributions enhance the underground carbon stock, and the soil carbon is metabolized by soil microorganisms (Kelting et al. 1998; Kuzyakov 2002; Lynch and Whipps 1990). Because a more diverse and labile energy source is available, the rhizosphere is a zone of enhanced microbial activity with a different species composition as compared to the surrounding soil. The endorhizosphere is a more intimate location of plant-microbe interactions, where mycorrhizae, pathogens, and symbionts such as NImage-fixing bacteria have primary access to root products (Lynch and Whipps 1990). The microflora and microfauna living outside of the rhizosphere obtain their energy from the secondary products that diffuse from the rhizosphere, as well as organic matter from the surface ground litter (Janssens et al. 1998; Kelting et al. 1998). The differences in environment will dictate the species composition of the microbes, thereby changing the values for soil respiration.  

Microbial interactions of the fungal type are well understood and studied for mycorrhizae. Vesicular-arbuscular mycorrhizal infections of plants with nodulated root systems fix more NImage than those plants without the fungal infection, at the cost of 6-11% of the plants’ net fixed carbon (Lynch and Whipps 1990).  

Of the carbon transferred to the root, between 40 and 90% is lost as rhizodepostion and respiration of roots and microorganisms (Lynch and Whipps 1990). Up to 50% of the belowground carbon is rhizodeposition from fine-root turnover (Kelting et al. 1998).  This data illustrates that plant roots are very important to microorganisms in the soil. For plants, the loss of carbon through rhizodeposition is not inherently detrimental. The ecological interactions in the rhizosphere are beneficial to the whole community as described by the microbial loop. Microbes generally compete with plants for nutrients, but under conditions where a plant is nutrient limited, it will release the photosynthates that it is unable to use. Microbial uptake of these exudates will help initiate the soil microbes into mineralizing nutrients (e.g. nitrogen), thus making nutrients more available in the soil for use by vegetation (Sylvia et al. 2005).  

## Case study: climate change 

Janssens et al. in the 1998 study treated a tree species with elevated COImage to test the outcome of a changing climate on forests. A summary of results can be given through an explanation of the biological relationships. The purpose of respiration is to release energy, yielding ATP and NADPH as products (Janssens et al. 1998). Elevated COImage levels increase the carbon supply for plants to photosynthesize. With the increase in carbon fixation there is a greater supply of carbohydrates to the roots, allowing the roots to sustain higher metabolic activity and specific respiration rates. The energy can be allocated in three ways: root maintenance, root growth, and nutrient uptake (Janssens et al. 1998; George 2003). All of these processes will increase, and lead to the higher values of rhizospheric respiration recorded by Janssens for Pinus sylvestris (Janssens et al. 1998). The relationship illustrated here shows that as a conditions change in favor of plant productivity, the microbial community also benefits. 

Respiration from the microbial community is dependent on biological factors such as plant species and growth conditions, as well as experimental conditions such as length of treatment and method of measurement (e.g. excised root or basal method) (Janssens et al. 1998; Kucera and Kirkham 1971). Other important factors that influence biological activity have been tested. For example, it was found that in prairies, the efflux of COImage from the soil increases exponentially with increase in temperature. Increase in temperature also results in greater microbial activity and respiration (Kucera and Kirkham 1971; Sylvia et al. 2005). Using treatments such as elevated COImage or temperature give information on the adaptability of plant species. A question to consider is if the microbial community will respond in a related way to the treatment. All in all, if accurate models are created from this type of data, predictions can be made for how ecological communities react to changing conditions.  

The way in which a plant allocates the three processes is important because it can influence the rhizosphere and the microbial community. Maintenance respiration represents over half of the total respiration by roots, and, in the case of Pinus taeda, 86% of the root respiration was recorded to be from root maintenance (George 2003). This component of root respiration provides energy to maintain ion gradients, repair membranes, and turnover and synthesize proteins. Most nitrogen in plants is incorporated into proteins; therefore maintenance respiration has a linear relationship with the concentration of nitrogen in the plant tissue (George 2003, Janssens et al. 1998). The nitrogen, carbon and other nutrients exudated by plant roots are used by microbial communities, as mentioned in the review of the rhizosphere.  

While Jenssens found the effect of elevated COImage on a tree species, this case study also illustrates the important relationship between plants and microbes (Janssens et al. 1998). The microbial loop concept explains the higher net primary productivity of a system since it accounts for the nutrients that become available due to decomposition and biological processes of microbes (DeLucia et al. 2007; Sylvia et al. 2005). 

## Case study: land use change 

As aforementioned in the previous case study, the impact of elevated COImage on root respiration is influenced by experimental and biological factors, thus the changes in root respiration is not expected to be the same for every system, whether it be a grassland, forest, or cropland. The vegetation type of a system influences and is influenced by physical soil properties. For example soil structure and texture can inhibit water infiltration, gas exchange, and the penetrability of the soil by roots and microorganisms (McGrath et al. 2001). Climatic gradients, such as temperature and moisture, along the landscape affect the decomposition rate of organic matter in the soil. Also, characteristic differences of microorganisms in grasslands and in forests are a source of variation. (Janssens et al. 1998; Kucera and Kirkham, 1971).  

Variation in root respiration means differences in carbon efflux. For studies aimed with exploring ways to reduce the COImage in the atmosphere or sequester carbon, land-use change is an area that knowledge of the microbial component of root respiration can be applied. For instance, in Kucera and Kirkham’s study of soil respiration a tallgrass prairie in Missouri was used, and 
60% of its total soil respiration was to be produced by microbial activity (Kucera and Kirkham 1971). In a prairie ecosystem, the root system is a principal source of organic matter, and since grasslands cover 30% of the world’s land surface, grasslands are an important portion of the global COImage flux (Jia et al. 2006). Jia et al. also used a grass species for their study: Leymus chinensis. The effect of soil water content on respiration was explored and found that the impact of water is limited unless conditions are at the far ends of the moisture continuum (Jia et al. 2006). 

Kelting conducted a study using forests, specifically the northern red oak, Quercus rubra. Using a method that combined two soil respiration measurement procedures, Kelting was able to determine that respiration of the plant roots, the rhizosphere, and the root-free soil to be 32, 20, and 48%, respectively (Kelting et al. 1998). Note that almost half of the total carbon efflux from the soil is due to microbial activity in the rhizosphere. The root-free soil respiration component is also due in part to microbial decomposition of the soil organic matter. 

Using information such as this, as in comparing the microbial community and CO2 efflux for two vegetation systems, is relevant to consider under land-use change circumstances. Land management decisions that are made with the carbon budget in mind would want to include the respiration of soil microorganisms, among the other components of soil respiration, when calculating for overall carbon efflux.

  Data collected in soil respiration studies can be used in models that will aim to understand the carbon budget of a system (DeLucia et al.  2007). While it has been clearly illustrated that  microbial activity is a significant component of soil respiration rate measurements, there are limited studies on specific species relationships or the community relationships of microorganisms with root respiration. There exists the challenge of differentiating the COImage produced by autotrophs and the COImage produced by heterotrophs.  

## Methods of measuring soil respiration 

The procedure for measuring root respiration and its components is not standardized (Jia et al. 2006; Kuzyakov 2002). All the methods are based on pulse labeling of shoots and subsequent monitoring of the carbon dioxide efflux from the soil. Common practice is to either infer (e.g. regressive relationship) or observe (e.g. isolate unknowns from total root respiration) the respiration rate values. However, some principles and assumptions vary between methods and do not yield the same data. Kuzyakov saw the need to conduct a comparison of methods study. It was determined that the exudate elution procedure is the only one that separates both carbon flows and that 50-60% of soil respiration is due to microbial deposition of rhizodeposites (Kuzyakov 2002).  

Microbial respiration rates are estimated indirectly by the relationships between soil respiration and root biomass. Mean dry root weight can be used to estimate root respiration (Jia et al. 2006). A specific species of bacteria found to have an important role in the rhizosphere are those in Enterobacter, as they can colonize early, fix NImage, and produce soil stabilizing agents (Lynch and Wipps 1990). One of the methods used to measure respiration is the basal method, however it overestimates root resp by 1/2.  Basal method gives root respiration, where the value for root respiration actually represents root respiration and rhizosphere respiration  together (Kelting et al. 1998). This illustrates the variability among the ways of obtaining soil respiration values. 
 
## Conclusion 

Methods of measuring soil respiration must be able to partition root and microorganism contributions to soil respiration so that carbon budgets and rate of turnover for soil organic matter can be calculated (Jia et al. 2006).  Root respiration is divided into three biological processes, with significant interactions occurring with microorganisms due to the products that the processes exude into the soil environment. A lack of studies specifically examining the community composition of soil microbes, points to a need for more advanced methods of collecting data from the rhizosphere. The importance of microbial activity in the soil, and the interactions of microbes with the vegetation and environmental conditions, is demonstrated through these studies. Accurate respiration measurements, at all levels, will lead to more accurate models and better informed land management decisions. 
 
 	 